==> serverless-google-cloudfunctions-2.4.1.tgz: package/deploy/lib/updateDeployment.js <==
'use strict';

const fs = require('fs');
const path = require('path');

const BbPromise = require('bluebird');

module.exports = {
  updateDeployment() {
    return BbPromise.bind(this)
      .then(this.getDeployment)
      .then(this.update);
  },

  getDeployment() {
    const params = {
      project: this.serverless.service.provider.project,
    };

    return this.provider
      .request('deploymentmanager', 'deployments', 'list', params)
      .then(response => {
        const deployment = response.deployments.find(dep => {
          const name = `sls-${this.serverless.service.service}-${this.options.stage}`;
          return dep.name === name;
        });

        return deployment;
      });
  },

  update(deployment) {
    this.serverless.cli.log('Updating deployment...');

    const filePath = path.join(
      this.serverless.config.servicePath,
      '.serverless',
      'configuration-template-update.yml'
    );

    const deploymentName = `sls-${this.serverless.service.service}-${this.options.stage}`;

    const params = {
      project: this.serverless.service.provider.project,
      deployment: deploymentName,
      resource: {
        name: deploymentName,
        fingerprint: deployment.fingerprint,
        target: {
          config: {
            content: fs.readFileSync(filePath).toString(),
          },
        },
      },
    };

    return this.provider
      .request('deploymentmanager', 'deployments', 'update', params)
      .then(() => this.monitorDeployment(deploymentName, 'update', 5000));
  },
};

==> serverless-google-cloudfunctions-4.3.0.tgz: package/deploy/lib/updateDeployment.js <==
'use strict';

const fs = require('fs');
const path = require('path');

const BbPromise = require('bluebird');

module.exports = {
  updateDeployment() {
    return BbPromise.bind(this).then(this.getDeployment).then(this.update);
  },

  getDeployment() {
    const params = {
      project: this.serverless.service.provider.project,
    };

    return this.provider
      .request('deploymentmanager', 'deployments', 'list', params)
      .then((response) => {
        const deployment = response.deployments.find((dep) => {
          const name = `sls-${this.serverless.service.service}-${this.options.stage}`;
          return dep.name === name;
        });

        return deployment;
      });
  },

  update(deployment) {
    this.serverless.cli.log('Updating deployment...');

    const filePath = path.join(
      this.serverless.config.servicePath,
      '.serverless',
      'configuration-template-update.yml'
    );

    const deploymentName = `sls-${this.serverless.service.service}-${this.options.stage}`;

    const params = {
      project: this.serverless.service.provider.project,
      deployment: deploymentName,
      resource: {
        name: deploymentName,
        fingerprint: deployment.fingerprint,
        target: {
          config: {
            content: fs.readFileSync(filePath).toString(),
          },
        },
      },
    };

    return this.provider
      .request('deploymentmanager', 'deployments', 'update', params)
      .then(() => this.monitorDeployment(deploymentName, 'update', 5000));
  },
};
